@@ -227,6 +227,7 @@ MEMORIAL_STADIUM = "16280"
 HUNTINGTON_BANK_FIELD = "19480"
 SANTIAGO_BERNABEU = "1353"
 OLYMPIC_STADIUM_BERLIN = "7696"
+CROKE_PARK = "4737"
 NFL_VENUE_IDENTITY_MAP = {
     # SportsDB
     "18784": EMPOWER_FIELD,
@@ -380,6 +381,7 @@ NFL_VENUE_IDENTITY_MAP = {
     "8748": NEO_QUIMICA_ARENA,
     "1353": SANTIAGO_BERNABEU,
     "7696": OLYMPIC_STADIUM_BERLIN,
+    "4737": CROKE_PARK,
 }
 NFL_PLAYER_IDENTITY_MAP: dict[str, str] = {}
 
